Re: the next step

2000-10-21 Thread Karl M. Hegbloom

> "Erik" == Erik Andersen <[EMAIL PROTECTED]> writes:

Erik> On Fri Oct 20, 2000 at 05:02:48PM -0700, Karl M. Hegbloom wrote:
>> 
>> Ok, cool.  Do you have a patch queue for us?

Erik> My mailbox.  I can also give folks write access...

 Ok; I'll just email anything I get time for.

Erik> The syscall layer is in a state of flux at the moment -- starting late last
Erik> night I began converting from asm syscall invocations to c ones, which makes 
Erik> my life a lot easier and makes it much easier to port to new architectures.
>> 
>> With any luck I'll understand the code well enough to help enough to
>> impress someone into hiring me.

Erik> Don't you have a few years of school left?   Getting anxious already?  
Erik> ;-)  

 Yes, a few more.

-- 
We should not penalize the conscientious to coddle those who run brain-dead software.
I am karlheg, of deB.ORG.  You will be freed.  Resistance is useful.
mailto:[EMAIL PROTECTED] (Karl M. Hegbloom)
http://www.debian.org/~karlheg


-- 
To UNSUBSCRIBE, email to [EMAIL PROTECTED]
with a subject of "unsubscribe". Trouble? Contact [EMAIL PROTECTED]




Re: Alternative root filesystem support

2000-10-21 Thread Goswin Brederlow

Glenn McGrath <[EMAIL PROTECTED]> writes:

> "Karl M. Hegbloom" wrote:
> > 
> > > "Goswin" == Goswin Brederlow <[EMAIL PROTECTED]> 
>writes:
> > 
> > Goswin> Hartmut Koptein <[EMAIL PROTECTED]> writes:
> > >> > Let's add one more bullet point for the new installer--namely,
> > >> > alternative root filesystem support.  I and my colleagues would just
> > >> > love to see ReiserFS support in woody's installer.
> > >>
> > >> Why reiserfs?  reiserfs is the bad guy, it doesen't support other
> > >> architectures then intel and only the 32 bit part.
> > 
> > Goswin> Doesn't reiser also have problems with raid and lvm?
> > 
> >  I spoke with a guy the other night who says he set up a reiserfs on a
> >  raid with lvm, iirc.  I'll try and have him put in here, if I can
> >  find his email and Cc him...
> > 
> >  Hey, Anthony?  What can you tell us about this?  Do you really know
> >  how to set up Reiserfs on RAID with lvm?

raid and lvm are different storries, although lvm can do striping.
I think reiser only had problems with raid5.

> For the woody installer it shouldnt be too difficult to handle reiser,
> lvm, raid, partition resizing etc.

A lot of places to change for the current dbootstrap. Trust me I
hunted them all down to get devfs working.

> As long as we have access to the module (or package) archive prior to
> creating the root filesystem we download whats required to make a raid
> partition, or reiserfs, and run it through a debconf menu to control its
> functionality.
> 
> One possible problem is that the modules we have the more demanding we
> will be on ram size as its all in ramdisk.

Anyone who wants raid/lvm/other fancy stuff on his root partition
should have a bit more ram than lowmem users. Also note that lvm on 7
is not possible without initrd tricks (which is rather stupid of lvm).

> An alternative to the everything in ramdisk idea would be to setup a
> loopfs somewhere on a local disk. This would complicate partitioning as
> we would have to check and maybe move the loop filesystem to another
> partition if the loopf is residing on the partition to be worked on.

If all else fails, take some out of swap.
Is ramfs swapable? If so, just use that.

MfG
Goswin


-- 
To UNSUBSCRIBE, email to [EMAIL PROTECTED]
with a subject of "unsubscribe". Trouble? Contact [EMAIL PROTECTED]




Re: [very preliminary] C debconf conceptual code

2000-10-21 Thread Anthony Towns

On Mon, Oct 02, 2000 at 10:18:30PM -0700, Randolph Chung wrote:
> Here's a bit of code that doesn't do anything useful yet, but illustrate
> some ideas about how a C-implementation of debconf may be built:
> http://auric.debian.org/~tausq/cdebconf-0.10.tgz

Well, at first glance it looks pretty good to me. It seems to segfault
pretty readily, but otherwise seems much more advanced than I expected.

> frontend {
>   default {
> driver "ncurses"; // use the ncurses frontend by default
>   };
> 
>   driver "ncurses" {module "modules/frontend/ncurses.so";};
>   driver "text" {module "modules/frontend/text.so"};
> };

It might be better to have the drivers autodetected based on what's in the
filesystem, rather than using a config file. That way each frontend can
have its own udeb and no one has to worry about messing with configuration
files from postinsts.

> database {
>   default {
> driver "textdb"; // use the textdb database backend by default
>   };
>   driver "textdb" {module "modules/db/textdb.so";};
> };

> if anything looks odd, it's because i wrote most of it on a plane :-)
> seriously though, comments/suggestions are most welcome. volunteers to
> work on this will be very much appreciated too!

So running ./debconf /var/lib/dpkg/info/netbase.config segfaults on my
part way through, but I'm not sure if that's just because I'm not running
it in the right environment or because of bugs, or what.

A better TODO list might be helpful. Or is there nothing more to do
(except maybe fix some bugs and add other frontends)?

Cheers,
aj

-- 
Anthony Towns <[EMAIL PROTECTED]> 
I don't speak for anyone save myself. GPG signed mail preferred.

  ``We reject: kings, presidents, and voting.
 We believe in: rough consensus and working code.''
  -- Dave Clark

 PGP signature


LANGUAGE_CHOOSER - continued

2000-10-21 Thread Marcin Owsiany

As I promised, here is the patch, which allows creation of root floppy
images with LANGUAGE_CHOOSER. I'm waiting for permission to commit it.

Possible problems I can see:

(1). Tested only on i386 (I only have access to such boxen), idepci flavor.
This should run on anything that has enough free space and framebuffer
support AFAIK.

The change in size between 2.2.16 idepci root.bin and a root.bin with
LANGUAGE_CHOOSER=true is about 375 KB gzipped, 1.1 MB raw.

Detailed description:

sizes of gzipped images:
idepci from 2.2.16:  957787
idepci with LC: 1342191

numbers of free inodes:
idepci from 2.2.16: 170
idepci with LC: 60

directories that changed sizes:

 11k  ->   12k  dev (fb, ptys)
 82k  -> 1021k  etc (messages)
952k  ->  968k  lib (libutf8_plug.so)
  1k  ->   32k  release_notes
815k  ->  924k  sbin(bterm, udbootstrap)
  0   ->   57k  unifont-reduced.bgf
206k  ->  208k  usr (bterm terminfo entry)

About 9 MB of memory is used just after startup   

Please try to test if all this works for different architectures, and tell
me if/why it doesn't.

(2). I added libutf8_plug.so to $LIBRARIES (under "determining set of required
libraries" in rootdisk.sh). I don't know if I should have, I thought this is
needed for library reduction, but now during the build tar cries that it
can't find the file (maybe because it is not run from top directory?):

I: copying required libraries to root filesystem
tar: ./utilities/bogl/libutf8_plug.so: Cannot stat: No such file or directory
tar: Error exit delayed from previous errors

This doesn't seem to break anything, though.

(3). Currently it won't build if you don't type 'make utils' earlier. Anyway,
IIRC this was also the case before, if you built e.g. only root.bin

(4). The release_notes.?? files in scripts/rootdisk/messages/ are not cleaned
on 'make clean' in top directory. Is this a right directory to keep them in
during build? If so, then I should add a cleaning command to top level
Makefile, right? If not, then where should they be kept?

(5). As I understand, LC won't be on all disk sets - only on those, which
have enough free space and framebuffer support. This will cause problems in
current build setup, where e.g. root1440idepci.bin contains a UTF-8
dbootstrap and things, but root1440.bin should be just plain old vanillia
root.bin, with standard.

This will mean we'll have to either:

1) make some kind of cleanup between building flavors with LC and those
   without it

 or

2) make two flavors of the things that differ between LC and non-LC
   versions, and name them differently, like:

root.bin depends on dbootstrap
while
root-idepci.bin depends on dbootstrap-lc

(dbootstrap is the plain old version, while dbootstrap-lc is linked against
patched versions of slang and newt)

Does anyone have some idea for 3) ?


regards
Marcin

-- 
++ The reason we come up with new versions
|Marcin Owsiany  | is not to fix bugs. It's the stupidest
|[EMAIL PROTECTED]| reason to buy a new version
++ I ever heard.- Bill Gates


Index: config
===
RCS file: /cvs/debian-boot/boot-floppies/config,v
retrieving revision 1.46
diff -u -r1.46 config
--- config  2000/08/24 06:24:35 1.46
+++ config  2000/10/21 21:10:36
@@ -82,7 +88,7 @@
 ##
 
 # whether to use the language chooser in dbootstrap, `true' or `false'
-USE_LANGUAGE_CHOOSER := false
+export USE_LANGUAGE_CHOOSER := true
 
 ifeq ($(USE_LANGUAGE_CHOOSER),true)
 ifneq ($(LINGUA),C)
-- 
%%% Antti-Juhani Kaijanaho % [EMAIL PROTECTED] % http://www.iki.fi/gaia/ %%%


-- 
To UNSUBSCRIBE, email to [EMAIL PROTECTED]
with a subject of "unsubscribe". Trouble? Contact [EMAIL PROTECTED]




Re: 2.2.18 and 2.2r1 release

2000-10-21 Thread Wichert Akkerman

Previously Wichert Akkerman wrote:
> I seriously need to fix a bug I introduced in modutils for 2.2r1,
> I'll work on that tonight.

Fixed and uploaded.

Wichert.

-- 
  _
 /   Nothing is fool-proof to a sufficiently talented fool \
| [EMAIL PROTECTED]  http://www.liacs.nl/~wichert/ |
| 1024D/2FA3BC2D 576E 100B 518D 2F16 36B0  2805 3CB8 9250 2FA3 BC2D |


-- 
To UNSUBSCRIBE, email to [EMAIL PROTECTED]
with a subject of "unsubscribe". Trouble? Contact [EMAIL PROTECTED]




Processed: 75303

2000-10-21 Thread Debian Bug Tracking System

Processing commands for [EMAIL PROTECTED]:

> retitle 75303 problems with installation-system.
Bug#75303: (no subject)
Changed Bug title.

> --
Stopping processing here.

Please contact me if you need assistance.

Darren Benham
(administrator, Debian Bugs database)


-- 
To UNSUBSCRIBE, email to [EMAIL PROTECTED]
with a subject of "unsubscribe". Trouble? Contact [EMAIL PROTECTED]




Processed: Bug#75304: problems with installation-system

2000-10-21 Thread Debian Bug Tracking System

Processing commands for [EMAIL PROTECTED]:

> merge 75304 75303
Bug#75303: (no subject)
Bug#75304: problems with installation-system
Merged 75303 75304.

> --
Stopping processing here.

Please contact me if you need assistance.

Darren Benham
(administrator, Debian Bugs database)


-- 
To UNSUBSCRIBE, email to [EMAIL PROTECTED]
with a subject of "unsubscribe". Trouble? Contact [EMAIL PROTECTED]




Re: Red Hat installer via CVS ?

2000-10-21 Thread Branden Robinson

On Sat, Oct 21, 2000 at 10:14:58AM +1100, Glenn McGrath wrote:
> Looks like Caldera's effort is under the QPL v1, thats the one that is
> incompatable with the GPL problems isnt it ?

That's correct, although when I was looking into Lizard (Caldera's effort)
for Progeny, there weren't any manifest license incompatibility problems
because it didn't link against any GPL'ed code.

We eventually gave up on Lizard for technical reasons.

-- 
G. Branden Robinson |
Debian GNU/Linux|   If God had intended for man to go about
[EMAIL PROTECTED]  |   naked, we would have been born that way.
http://www.debian.org/~branden/ |

 PGP signature


Bug#75304: problems with installation-system

2000-10-21 Thread C . R de Groot

Package: boot-floppies
Version: Debian GNU/Linux 2.2 potato
architecture: i686
model: no-name pII 350
memory: 64MB
scsi: none
cd-rom:   -ATAPI 36X
-Philips 2/2/24 cdr/cdrw
network card:  ne2000 (Realtek 8019 ISA)
pcmcia:  none
harddisk: Maxtor DiamondMax 27gig 7200rpm IDE
videocard: Voodoo 3 2000 PCI
audio: ESS Technology Maestro 2 (onboard chip)
problem description:

When i try to install Debian 2.2, The kernel hangs when it's booting. 
It gives a lot of "normal" kernel-messages and it hangs after the message "IBM
MCA SCSI: No Microchannel-bus support present -> Aborting".
I couldnt even get into the installation menu :/
I verified if there was conflicting hardware on my computer, there was not. I
verified my bios settings, and i disabled Video BIOS Shadow, after that it
still hanged.
I have used Linux-Mandrake 7.0 & 7.1 before for 4 months without any problem
with both the installation and running itself.
I've asked on several linux channels on irc, if anybody ever happened this or
if everybody know how i could get it working, nobody knew. 
I heard a lot of good things about Debian and i wanted to try it. I hope i am
able to install it later :)

Greets Jogchem de Groot

P.S. If there is any extra information required, just ask me :)
---


-- 
To UNSUBSCRIBE, email to [EMAIL PROTECTED]
with a subject of "unsubscribe". Trouble? Contact [EMAIL PROTECTED]




Bug#75303: (no subject)

2000-10-21 Thread C . R de Groot

Package: boot-floppies
Version: Debian GNU/Linux 2.2 potato
architecture: i686
model: no-name pII 350
memory: 64MB
scsi: none
cd-rom:   -ATAPI 36X
-Philips 2/2/24 cdr/cdrw
network card:  ne2000 (Realtek 8019 ISA)
pcmcia:  none
harddisk: Maxtor DiamondMax 27gig 7200rpm IDE
videocard: Voodoo 3 2000 PCI
audio: ESS Technology Maestro 2 (onboard chip)
problem description:

When i try to install Debian 2.2, The kernel hangs when it's booting. 
It gives a lot of "normal" kernel-messages and it hangs after the message "IBM
MCA SCSI: No Microchannel-bus support present -> Aborting".
I couldnt even get into the installation menu :/
I verified if there was conflicting hardware on my computer, there was not. I
verified my bios settings, and i disabled Video BIOS Shadow, after that it
still hanged.
I have used Linux-Mandrake 7.0 & 7.1 before for 4 months without any problem
with both the installation and running itself.
I've asked on several linux channels on irc, if anybody ever happened this or
if everybody know how i could get it working, nobody knew. 
I heard a lot of good things about Debian and i wanted to try it. I hope i am
able to install it later :)

Greets Jogchem de Groot

P.S. If there is any extra information required, just ask me :)




-- 
To UNSUBSCRIBE, email to [EMAIL PROTECTED]
with a subject of "unsubscribe". Trouble? Contact [EMAIL PROTECTED]




Re: LANGUAGE_CHOOSER on the root disk

2000-10-21 Thread Marcin Owsiany

On Sat, Oct 21, 2000 at 07:01:21PM +0200, Marcin Owsiany wrote:
> 
> However this has some problems, namely bterm segfaults on the root floppy.
> Gdb says:
[...]
> #0  0x8049314 in main (argc=3, argv=0xbe84) at bterm.c:245
> 245 FD_SET(ptyfd, &fds);
[...]
> This means I need help again (i don't know much about ptys).

Silly me :-)

It segfaulted because ptys don't exist on root floppy and because nothing
checks return value of get_ptytty

Anyway, I've got it working after MAKEDEV-ing pty and copying bterm terminfo
to the floppy. I'll post a full patch this night.

Regards
Marcin

-- 
++ The reason we come up with new versions
|Marcin Owsiany  | is not to fix bugs. It's the stupidest
|[EMAIL PROTECTED]| reason to buy a new version
++ I ever heard.- Bill Gates


-- 
To UNSUBSCRIBE, email to [EMAIL PROTECTED]
with a subject of "unsubscribe". Trouble? Contact [EMAIL PROTECTED]




LANGUAGE_CHOOSER on the root disk

2000-10-21 Thread Marcin Owsiany

Hi!

I managed to change the makefiles, so (almost) all things needed for
LANGUAGE_CHOOSER are placed on the root floppy.

I'm attaching a patch.

Currently only the following things still have to be done by hand IIRC:
 - copy unifont-reduced.bgf to the root dir on the root floppy
 - MAKEDEV fb on the floppy
 - change inittab so that instead of /sbin/dbootstrap, init runs
LC_CTYPE=C.UTF-8 LD_PRELOAD=/lib/libutf8_plug.so /sbin/bterm -f /unifont-reduced.bgf 
/sbin/dbootstrap

(Just uncompress the image, loop mount it, make the changes, umount and gzip
it back)

Also run 'make utils' before everything else - some things don't yet depend
on everything they should

Should I commit it to CVS? I tried to avoid changing anything that is run
without USE_LANGUAGE_CHOOSER=true

However this has some problems, namely bterm segfaults on the root floppy.
Gdb says:

Core was generated by /sbin/bterm -f /unifont-reduced.bgf'.
Program terminated with signal 11, Segmentation fault.
Reading symbols from /lib/libutf8_plug.so...done.
Reading symbols from /lib/libc.so.6...done.
Reading symbols from /lib/libdl.so.2...done.
Reading symbols from /lib/ld-linux.so.2...done.
#0  0x8049314 in main (argc=3, argv=0xbe84) at bterm.c:245
245 FD_SET(ptyfd, &fds);
(gdb) where
#0  0x8049314 in main (argc=3, argv=0xbe84) at bterm.c:245

This means I need help again (i don't know much about ptys).

regards

Marcin
-- 
++ The reason we come up with new versions
|Marcin Owsiany  | is not to fix bugs. It's the stupidest
|[EMAIL PROTECTED]| reason to buy a new version
++ I ever heard.- Bill Gates


Index: config
===
RCS file: /cvs/debian-boot/boot-floppies/config,v
retrieving revision 1.46
diff -u -r1.46 config
--- config  2000/08/24 06:24:35 1.46
+++ config  2000/10/21 16:34:04
@@ -82,7 +88,7 @@
 ##
 
 # whether to use the language chooser in dbootstrap, `true' or `false'
-USE_LANGUAGE_CHOOSER := false
+export USE_LANGUAGE_CHOOSER := true
 
 ifeq ($(USE_LANGUAGE_CHOOSER),true)
 ifneq ($(LINGUA),C)
Index: rootdisk.sh
===
RCS file: /cvs/debian-boot/boot-floppies/rootdisk.sh,v
retrieving revision 1.169
diff -u -r1.169 rootdisk.sh
--- rootdisk.sh 2000/10/15 06:43:40 1.169
+++ rootdisk.sh 2000/10/21 16:34:07
@@ -10,6 +10,8 @@
 
 export LANG=C
 
+linguas="cs en es fr hu ja pt sk tr de eo fi hr it pl ru sv"
+
 # configuration
 fstype=ext2
 if [ ${arch} = i386 -o ${arch} = m68k ]; then
@@ -131,6 +133,13 @@
 
 make_tmpdir $mnt
 
+if [ "$USE_LANGUAGE_CHOOSER" = "true" ]
+then
+   info "this disk will contain language chooser"
+   info "increasing blocks number by 1000"
+   blocks=$[$blocks+1000]
+fi
+
 info "making disk image loop filesystem, size ${blocks}k"
 
 # zero the entire disk, so that when we compress the raw disk image,
@@ -437,6 +446,11 @@
 info "determining set of required libraries"
 LIBRARIES=""
 EXECUTABLES="$R/bin/* $R/sbin/* $R/usr/bin/* ./utilities/busybox/busybox 
./utilities/dbootstrap/dbootstrap"
+if [ "$USE_LANGUAGE_CHOOSER" = "true" ]
+then
+   EXECUTABLES="$EXECUTABLES ./utilities/bogl/bterm"
+   LIBRARIES="$LIBRARIES ./utilities/bogl/libutf8_plug.so"
+fi
 
 #   ldconfig.new is statically linked
 EXECUTABLES=`echo $EXECUTABLES | sed s%$R/sbin/ldconfig.new%%g`
@@ -492,8 +506,20 @@
 
 cp utilities/dbootstrap/dbootstrap $R/sbin/
 mkdir -p $R/etc
-make -C utilities/dbootstrap/po $language.trm
-cp utilities/dbootstrap/po/$language.trm $R/etc/messages.trm
+if [ "$USE_LANGUAGE_CHOOSER" = "true" ]
+then
+   cp utilities/bogl/bterm $R/sbin/
+   cp utilities/bogl/libutf8_plug.so $R/lib
+   make -C utilities/dbootstrap/po all-utf
+   #linguas defined at the beginning of the script
+   for lang in $linguas
+   do
+   cp utilities/dbootstrap/po/utf/$lang.trm $R/etc/messages.$lang
+   done
+else
+   make -C utilities/dbootstrap/po $language.trm
+   cp utilities/dbootstrap/po/$language.trm $R/etc/messages.trm
+fi
 
 # no keymaps for BVME and MVME
 if [ "$system" != bvme6000 -a "$system" != mvme16x -a "$system" != mvme147 ]; then
@@ -540,14 +566,14 @@
 -D__username__="${MAINTAINER}" \
 >$R/release_notes.en
 
-for lang in `awk '{ print $$1 }' < $scripts/messages/languages`
+for lang in `awk '{ print $1 }' < $scripts/messages/languages`
 do
 m4 $scripts/messages/$lang/release_notes \
 -D__debianversion__=$debianversion \
 -D__date__="`date +%Y-%m-%d`" \
 -D__floppyversion__="`dpkg-parsechangelog | awk -- '/^Version/ {print 
$2}'`" \
 -D__username__="${MAINTAINER}" |
-iconv -f `grep "^$lang " $scripts/messages/languages | awk '{ print $$2 }'` 
-t utf-8 > $R/release_notes.$lang
+iconv -f `grep "^$lang " $scripts/messages/languages | awk '{

Re: FALSE == 1

2000-10-21 Thread Nick Holgate

> Since they were there, they then got used for other things with
> the result that busybox now needs about 1 day worth of work to reverse
> things.

It would appear obvious to me that instead if changing the semantics of
the code to match the "proper" definitions of TRUE and FALSE, you should
define two new symbols, perhaps:

  #define GOOD 0
  #define EVIL 1

Then perform a simple search and replace of TRUE and FALSE. I'm sure
this wouldn't have taken more than 15 minutes.


Nick


Nick Holgate <[EMAIL PROTECTED]>
GPG key from public servers : Key ID FD9C18AF
Fingerprint = 9DCA EDEA D5C5 57DA 23F3  1A2B 2273 5645 FD9C 18AF


Index: rootdisk.sh
===
RCS file: /cvs/debian-boot/boot-floppies/rootdisk.sh,v
retrieving revision 1.169
diff -u -r1.169 rootdisk.sh
--- rootdisk.sh 2000/10/15 06:43:40 1.169
+++ rootdisk.sh 2000/10/21 21:10:41
@@ -4,6 +4,7 @@
 # Enrique Zanardi 1998
 # Hartmut Koptein, 1998; powerpc support
 # Matej Vela, 1998 [non-ISO-8859-1 charset support]
+# Marcin Owsiany, 2000 [LANGUAGE_CHOOSER integration]
 # This is free software under the GNU General Public License.
 
 . ./common.sh
@@ -131,6 +132,13 @@
 
 make_tmpdir $mnt
 
+if [ "$USE_LANGUAGE_CHOOSER" = "true" ]
+then
+   info "this disk will contain language chooser"
+   info "increasing blocks number by 1000"
+   blocks=$[$blocks+1000]
+fi
+
 info "making disk image loop filesystem, size ${blocks}k"
 
 # zero the entire disk, so that when we compress the raw disk image,
@@ -235,8 +243,8 @@
 miscdevs="initrd rtc loop lp fd md ram0 consoleonly"
 alldevs="$ttydevs $idedevs $scsidevs $miscdevs"
 
-# add devices for japanese installer
-if [ "$LINGUA" = "ja" ] ; then
+# add devices for japanese installer and LANGUAGE_CHOOSER
+if [ "$LINGUA" = "ja" -o "$USE_LANGUAGE_CHOOSER" = 'true' ] ; then
alldevs="$alldevs fb0 ptyp ptyq ptyr ptys"
 fi
 
@@ -29

Re: busybox in main

2000-10-21 Thread Antti-Juhani Kaijanaho

On 20001018T104910-0600, Erik Andersen wrote:
> Before packaging it up, I asked on debian-boot if policy
> compliance was required for this package, or if it should only contain the
> binaries.  In that discussion, we made the decision that installer specific
> packages do not need to be policy compliant.  This decision was made by Joey
> Hess, project leader for the woody debian-installer.

Oh, I was not aware that Joey is the current policy czar.

(For the record, we don't have policy czars anymore.)

> Until I am informed by
> the woody debian-installer project leader that something else has been decided,
> I will continue to assuming that we are merely waiting for the archive to be
> updated to support debian-installer specific packaged with a new "installer"
> section.

You are actually waiting for a decision to be made.  The debian-installer
project leader does not have the authority to decide these things -
what you are suggesting requires a consensus among Debian developers at
minimum (ie. a flamewar on -devel) and possibly a Debian Policy change
(which requires certain hoops to be jumped through on the -policy list).
It definitely *cannot* be decided by the install system team alone.
(Which is, BTW, a point I already made those months ago in my reject
message.)

-- 
To UNSUBSCRIBE, email to [EMAIL PROTECTED]
with a subject of "unsubscribe". Trouble? Contact [EMAIL PROTECTED]




Processed: Fixed in NMU boot-floppies 2.2.17

2000-10-21 Thread Debian Bug Tracking System

Processing commands for [EMAIL PROTECTED]:

> severity 11000 fixed
Bug#11000: [CVS-fixed] Installation: should allow adding append to lilo install
Bug#25848: [CVS-fixed] bootdisk: Keep "append=*" parameters during installation 
proccess.
Severity set to `fixed'.

> severity 25848 fixed
Bug#25848: [CVS-fixed] bootdisk: Keep "append=*" parameters during installation 
proccess.
Bug#11000: [CVS-fixed] Installation: should allow adding append to lilo install
Severity set to `fixed'.

> severity 31449 fixed
Bug#31449: suboptimal behavior when mounting as root already installed system
Severity set to `fixed'.

> severity 57609 fixed
Bug#57609: boot-floppies: Putting fr-latin0 keyboard map in the boot floppies?
Severity set to `fixed'.

> severity 57733 fixed
Bug#57733: bootdisk: File selection boxes don't work if non-existent directory is given
Severity set to `fixed'.

> severity 61373 fixed
Bug#61373: [CVS-fixed] install path must end with / if it's symlink
Severity set to `fixed'.

> severity 61693 fixed
Bug#61693: boot-floppies: confused when configuring the cdrom source
Severity set to `fixed'.

> severity 64349 fixed
Bug#64349: boot-floppy: insists on path image-1.44/rescue.bin
Bug#66326: [CVS-fixed] images-1.44/rescue.bin
Severity set to `fixed'.

> severity 66030 fixed
Bug#66030: [CVS-fixed] Tries to read past end of driver-3.bin
Severity set to `fixed'.

> severity 66326 fixed
Bug#66326: [CVS-fixed] images-1.44/rescue.bin
Bug#64349: boot-floppy: insists on path image-1.44/rescue.bin
Severity set to `fixed'.

> severity 67082 fixed
Bug#67082: [CVS-fixed] "Choose debian archive" box confusing
Severity set to `fixed'.

> severity 67378 fixed
Bug#67378: [CVS-fixed] Potato test-cycle-1 omits /dev/sg*
Severity set to `fixed'.

> severity 67898 fixed
Bug#67898: [CVS-fixed] doc: missing target of Release Notes link
Severity set to `fixed'.

> severity 67900 fixed
Bug#67900: [CVS-fixed] doc: "FIXME" text remains (because not labeled "FIXME")
Severity set to `fixed'.

> severity 68021 fixed
Bug#68021: [CVS-fixed] Can't locate/configure modules with compact set
Bug#70878: [CVS-fixed] Module installation breaks if kernel installation fails once
Severity set to `fixed'.

> severity 68517 fixed
Bug#68517: [CVS-fixed] Not enough RAID ida devices
Severity set to `fixed'.

> severity 68630 fixed
Bug number 68630 not found.

> severity 68659 fixed
Bug#68659: [CVS-fixed] root disk filesystem shouldn't use new ext2 extensions
Severity set to `fixed'.

> severity 68900 fixed
Bug#68900: [CVS-fixed] Misterious boot-floppies error
Severity set to `fixed'.

> severity 68911 fixed
Bug#68911: [fixed in CVS] dbootstrap.h missing
Severity set to `fixed'.

> severity 69141 fixed
Bug#69141: [CVS-fixed] boot-floppies: Can dd with volume management on in Solaris
Severity set to `fixed'.

> severity 69158 fixed
Bug#69158: [CVS-fixed] boot-floppies: Installer doesn't eject floppies on PowerPC 
PowerMacs
Severity set to `fixed'.

> severity 69620 fixed
Bug#69620: [CVS-fixed] Is section 1.7 still required?
Severity set to `fixed'.

> severity 69959 fixed
Bug#69959: [CVS-fixed] 1.2M root.bin is just nulls
Bug#69970: [CVS-fixed] images-1.20/root.bin consists entirely of nulls
Severity set to `fixed'.

> severity 69970 fixed
Bug#69970: [CVS-fixed] images-1.20/root.bin consists entirely of nulls
Bug#69959: [CVS-fixed] 1.2M root.bin is just nulls
Severity set to `fixed'.

> severity 71080 fixed
Bug#71080: [CVS-fixed] errors in documentation chapter 8
Severity set to `fixed'.

> quit
Stopping processing here.

Please contact me if you need assistance.

Darren Benham
(administrator, Debian Bugs database)


-- 
To UNSUBSCRIBE, email to [EMAIL PROTECTED]
with a subject of "unsubscribe". Trouble? Contact [EMAIL PROTECTED]